added more host functions and tests

Change-Id: I9904e65e14c5479ba33d836c5c0b763cb5af71e3
Cette révision appartient à :
Aditya Atluri
2016-06-15 11:45:19 -05:00
Parent 59e3dabf29
révision 7cb45e2d87
3 fichiers modifiés avec 156 ajouts et 44 suppressions
+5 -2
Voir le fichier
@@ -123,17 +123,20 @@ __device__ float coshf(float x);
__device__ float cyl_bessel_i0f(float x);
__device__ float cyl_bessel_i1f(float x);
__device__ float erfcf(float x);
__device__ float erfcinvf(float y);
__device__ float erfcinvf(float y);
__host__ float erfcinvf(float y);
__device__ float erfcxf(float x);
__host__ float erfcxf(float x);
__device__ float erff(float x);
__device__ float erfinvf(float y);
__host__ float erfinvf(float y);
__device__ float exp10f(float x);
__device__ float exp2f(float x);
__device__ float expf(float x);
__device__ float expm1f(float x);
__device__ float fabsf(float x);
__device__ float fdimf(float x, float y);
__device__ float fdividef(float x, float y);
__device__ __host__ float fdividef(float x, float y);
__device__ float floorf(float x);
__device__ float fmaf(float x, float y, float z);
__device__ float fmaxf(float x, float y);